==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/UserListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UserListBuilder extends io.fabric8.openshift.api.model.UserListFluentImpl<io.fabric8.openshift.api.model.UserListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.UserList,io.fabric8.openshift.api.model.UserListBuilder>{
  public UserListBuilder() {
    this(false);
  }
  public UserListBuilder(java.lang.Boolean validationEnabled) {
    this(new UserList(), validationEnabled);
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserListFluent<?> fluent) {
    this(fluent, false);
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new UserList(), validationEnabled);
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserListFluent<?> fluent,io.fabric8.openshift.api.model.UserList instance) {
    this(fluent, instance, false);
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserListFluent<?> fluent,io.fabric8.openshift.api.model.UserList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserList instance) {
    this(instance,false);
  }
  public UserListBuilder(io.fabric8.openshift.api.model.UserList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.UserListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.UserList build() {
    UserList buildable = new UserList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UserListBuilder that = (UserListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.4.1-sources.jar: io/fabric8/openshift/api/model/UserListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UserListBuilder extends UserListFluentImpl<UserListBuilder> implements VisitableBuilder<UserList,UserListBuilder>{
  public UserListBuilder() {
    this(false);
  }
  public UserListBuilder(Boolean validationEnabled) {
    this(new UserList(), validationEnabled);
  }
  public UserListBuilder(UserListFluent<?> fluent) {
    this(fluent, false);
  }
  public UserListBuilder(UserListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UserList(), validationEnabled);
  }
  public UserListBuilder(UserListFluent<?> fluent,UserList instance) {
    this(fluent, instance, false);
  }
  public UserListBuilder(UserListFluent<?> fluent,UserList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UserListBuilder(UserList instance) {
    this(instance,false);
  }
  public UserListBuilder(UserList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  UserListFluent<?> fluent;
  Boolean validationEnabled;
  public UserList build() {
    UserList buildable = new UserList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
